@@ -6,10 +6,10 @@ import bisect
 from itertools import zip_longest, chain
 import binascii
 
-import ccxt
 import pendulum
 
 from uxapi import register_exchange
+from uxapi.exchanges.ccxt.okex import okex
 from uxapi import UXSymbol
 from uxapi import WSHandler
 from uxapi import UXPatch
@@ -21,7 +21,7 @@ from uxapi.helpers import (
 
 
 @register_exchange('okex')
-class Okex(UXPatch, ccxt.okex):
+class Okex(UXPatch, okex):
     def __init__(self, market_type, config=None):
         return super().__init__(market_type, deep_extend({
             'options': {
@@ -81,11 +81,11 @@ class Okex(UXPatch, ccxt.okex):
                     'mark_price': 'swap/mark_price:{symbol}',
                 },
                 'option': {
-                    'position': 'option/position:{currency}',
-                    'account': 'option/account:{currency}',
-                    'myorder': 'option/order:{currency}',
-                    'instruments': 'option/instruments:{currency}',
-                    'summary': 'option/summary:{currency}',
+                    'position': 'option/position:{currency}-USD',
+                    'account': 'option/account:{currency}-USD',
+                    'myorder': 'option/order:{currency}-USD',
+                    'instruments': 'option/instruments:{currency}-USD',
+                    'summary': 'option/summary:{currency}-USD',
                     'ticker': 'option/ticker:{symbol}',
                     'orderbook': 'option/depth{level}:{symbol}',
                     'trade': 'option/trade:{symbol}',
@@ -101,32 +101,23 @@ class Okex(UXPatch, ccxt.okex):
     def _fetch_markets(self, params=None):
         markets = super()._fetch_markets(params)
         for market in markets:
-            contract_value = self.safe_float(market['info'], 'contract_val')
-            if contract_value:
-                market['contractValue'] = contract_value
             underlying = self.safe_string(market['info'], 'underlying')
             if underlying and underlying.endswith('-USDT'):
                 quote, base = underlying.split('-')
                 market['base'] = market['baseId'] = base
                 market['quote'] = market['quoteId'] = quote
-            if market['type'] == 'futures':
-                delivery_date = self.safe_string(market['info'], 'delivery')
-                if delivery_date:
-                    delivery_time = pendulum.from_format(delivery_date, 'YYYY-MM-DD')
-                    delivery_time = delivery_time.add(hours=self.deliveryHourUTC)
-                    market['deliveryTime'] = delivery_time.to_iso8601_string()
-                else:
-                    market['deliveryTime'] = None
-        return markets
 
-    def _create_order(self, uxsymbol, type, side, amount, price, params):
-        if uxsymbol.market_type in ('futures', 'swap'):
-            amount = self.amount_to_precision(self.convert_symbol(uxsymbol), amount)
-            if type == 'limit':
-                # '1': buy & open long
-                # '2': sell & open short
-                type = '1' if side == 'buy' else '2'
-        return super()._create_order(uxsymbol, type, side, amount, price, params)
+            contract_value = self.safe_float(market['info'], 'contract_val')
+            if contract_value:
+                market['contractValue'] = contract_value
+
+            if market['futures']:
+                delivery_time = pendulum.parse(self.safe_string(market['info'], 'delivery'))
+                delivery_time = delivery_time.add(hours=self.deliveryHourUTC)
+                market['deliveryTime'] = delivery_time.to_iso8601_string()
+            elif market['option']:
+                market['deliveryTime'] = market['info']['delivery']
+        return markets
 
     def order_book_merger(self):
         return OkexOrderBookMerger()
@@ -158,12 +149,11 @@ class Okex(UXPatch, ccxt.okex):
 
         if uxsymbol.market_type == 'option':
             base = uxsymbol.base
-            quote = uxsymbol.quote
             dt = pendulum.parse(uxsymbol.contract_expiration)
             expiration = dt.format('YYMMDD')
             strike_price = uxsymbol.option_strike_price
             call_or_put = uxsymbol.option_type
-            return f'{base}-{quote}-{expiration}-{strike_price}-{call_or_put}'
+            return f'{base}-USD-{expiration}-{strike_price}-{call_or_put}'
 
         raise ValueError(f'invalid symbol: {uxsymbol}')
 
